flask-s3
========

|Build Status| |Coverage Status| |Analytics| |PyPI Version|

Seamlessly serve the static assets of your Flask app from Amazon S3.

Maintainers
-----------

Flask-S3 is maintained by @e-dard, @eriktaubeneck and @SunDwarf.

Installation
------------

Install Flask-S3 via pypi:

::

    pip install flask-s3
     

Or, install the latest development version:

::

    pip install git+https://github.com/e-dard/flask-s3

Documentation
-------------

The latest documentation for Flask-S3 can be found
`here <https://flask-s3.readthedocs.org/en/latest/>`__.

.. |Build Status| image:: https://travis-ci.org/e-dard/flask-s3.svg?branch=master
   :target: https://travis-ci.org/e-dard/flask-s3
.. |Coverage Status| image:: https://coveralls.io/repos/e-dard/flask-s3/badge.svg?branch=master&service=github
   :target: https://coveralls.io/github/e-dard/flask-s3?branch=master
.. |Analytics| image:: https://ga-beacon.appspot.com/UA-35880013-3/flask-s3/readme
   :target: https://github.com/igrigorik/ga-beacon
.. |PyPI Version| image:: https://img.shields.io/pypi/v/Flask-S3.svg
   :target: https://pypi.python.org/pypi/Flask-S3
